configure_inset: Configure transformations underpinning a map inset
Description
This specialises ggmapinset::configure_inset() to allow the centre
to be specified as a location. The centroid of that location is used as the
inset's centre.
Usage
configure_inset(
centre = NULL,
scale = NULL,
translation = NULL,
radius = NULL,
units = "km",
feature_type = NA
)
Value
An inset configuration object.
Arguments
centre
Coordinates of the inset centre. Can instead be the name of a
geographic feature if feature_type is also provided.
scale
Zoom scale: values larger than one will make the circle bigger.
translation
Translate (shift) the inset. This can be an
st_point or simply a vector of length 2 containing the x and y
offsets respectively.
radius
Radius of the inset circle.
units
Base length unit (e.g. "km" or "mi").
See ggmapinset::configure_inset() for supported values.
feature_type
Type of map feature. See feature_types() for a list of
registered types. If NA, the type is guessed based on the values in
feature_names.